#!/usr/bin/python
import sys

def ez():
  if len(sys.argv) < 3:
    print '<usage> ml_easy_peer_grade [YOUR_ID] [YOUR_LAST_NAME] [nth_LAST_NAME]*'
  else:
    args = sys.argv[1:]
    f = open('{}.txt'.format(args[0]), 'w')
    s = "{0[0]} {0[1]}\n".format(args)
    last_names = args[2:]
    for name in last_names:
      s += "{} 1\n".format(name)
    f.write(s)
    f.close() 



from distutils.core import setup
setup(
  name = 'ml_easy_peer_grade',
  packages = ['ml_easy_peer_grade'], 
  version = '0.16',
  scripts=['bin/ml_easy_peer_grade'],
  description = 'Ez peer grade your project members, exclusive to privileged Bilkent students',
  author = 'Cagdas Oztekin',
  author_email = 'lorrabarra@gmail.com',
  url = 'https://github.com/cagdass/ml-easy-peer-grade', 
  download_url = 'https://github.com/cagdass/ml-easy-peer-grade/tarball/0.1',
  keywords = ['testing'],
  classifiers = [],
)
